==> ArrayExpress_1.10.0.zip: ArrayExpress/doc/ArrayExpress.R <==
###################################################
### chunk number 1: queryAE
###################################################
#line 42 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
library("ArrayExpress")
sets = queryAE(keywords = "pneumonia", species = "homo+sapiens")


###################################################
### chunk number 2: ArrayExpress-raw
###################################################
#line 82 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
rawset = ArrayExpress("E-MEXP-1422")


###################################################
### chunk number 3: ArrayExpress-columnsneeded
###################################################
#line 96 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
eset = try(ArrayExpress("E-DKFZ-1"))


###################################################
### chunk number 4: ArrayExpress-withcolumns
###################################################
#line 103 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
eset = ArrayExpress("E-DKFZ-1",
  rawcol=list(R="Software Unknown:Foreground red",
    G="Software Unknown:Foreground green",
    Rb="Software Unknown:Background red" ,
    Gb="Software Unknown:Background green"))


###################################################
### chunk number 5: getAE-full
###################################################
#line 118 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
mexp1422 = getAE("E-MEXP-1422", type = "full")


###################################################
### chunk number 6: magetab2bioc-full
###################################################
#line 143 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
rawset= magetab2bioc(files = mexp1422)


###################################################
### chunk number 7: getcolproc
###################################################
#line 161 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
cn = getcolproc(mexp1422)
show(cn)


###################################################
### chunk number 8: procset
###################################################
#line 175 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
proset = procset(mexp1422, cn[2])


###################################################
### chunk number 9: import
###################################################
#line 186 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
AEset = ArrayExpress("E-MEXP-1416")


###################################################
### chunk number 10: norm
###################################################
#line 191 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
library("affy")
AEsetnorm = rma(AEset)


###################################################
### chunk number 11: fac
###################################################
#line 197 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
fac = grep("Factor.Value",colnames(pData(AEset)), value=T)


###################################################
### chunk number 12: qanorm eval=FALSE
###################################################
## #line 206 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
## if (suppressWarnings(require("arrayQualityMetrics", quietly=TRUE))) {
##   qanorm = arrayQualityMetrics(AEsetnorm, 
##     outdir = "QAnorm", 
##     intgroup = fac, 
##     grouprep = TRUE)
## }


###################################################
### chunk number 13: limma
###################################################
#line 216 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpCG0FET/R.INSTALL269969a8/ArrayExpress/inst/doc/ArrayExpress.Rnw"
library("limma")
facs =  pData(AEset)[,fac]
facs[facs[,2]=="female",2]="F"
facs[facs[,2]=="male",2]="M"
facs[facs[,1]=="Parkinson disease",1]="parkinson"
facs = paste(facs[,1],facs[,2], sep=".")
f = factor(facs)
design = model.matrix(~0+f)
colnames(design) = levels(f)
fit = lmFit(AEsetnorm, design)
cont.matrix = makeContrasts(normal.FvsM = normal.F-normal.M,             
    parkinson.FvsM = parkinson.F-parkinson.M,  
    Diff=(parkinson.F-parkinson.M)-(normal.F-normal.M),
    levels=design)
fit2 = contrasts.fit(fit, cont.matrix)
fit2 = eBayes(fit2)
res = topTable(fit2, coef = "parkinson.FvsM", adjust = "BH")

==> ArrayExpress_1.12.1.zip: ArrayExpress/doc/ArrayExpress.R <==
### R code from vignette source 'ArrayExpress.Rnw'

###################################################
### code chunk number 1: queryAE
###################################################
library("ArrayExpress")
sets = queryAE(keywords = "pneumonia", species = "homo+sapiens")


###################################################
### code chunk number 2: ArrayExpress-raw
###################################################
rawset = ArrayExpress("E-MEXP-1422")


###################################################
### code chunk number 3: ArrayExpress-columnsneeded
###################################################
eset = try(ArrayExpress("E-MEXP-1870"))


###################################################
### code chunk number 4: ArrayExpress-withcolumns
###################################################
eset = ArrayExpress("E-MEXP-1870",
  rawcol=list(R="ScanArray Express:F650 Mean",
    G="ScanArray Express:F550 Mean",
    Rb="ScanArray Express:B650 Mean",
    Gb="ScanArray Express:B550 Mean"))


###################################################
### code chunk number 5: getAE-full
###################################################
mexp1422 = getAE("E-MEXP-1422", type = "full")


###################################################
### code chunk number 6: magetab2bioc-full
###################################################
rawset= magetab2bioc(files = mexp1422)


###################################################
### code chunk number 7: getcolproc
###################################################
cn = getcolproc(mexp1422)
show(cn)


###################################################
### code chunk number 8: procset
###################################################
proset = procset(mexp1422, cn[2])


###################################################
### code chunk number 9: import
###################################################
AEset = ArrayExpress("E-MEXP-1416")


###################################################
### code chunk number 10: norm
###################################################
library("affy")
AEsetnorm = rma(AEset)


###################################################
### code chunk number 11: fac
###################################################
fac = grep("Factor.Value",colnames(pData(AEset)), value=T)


###################################################
### code chunk number 12: qanorm (eval = FALSE)
###################################################
## if (suppressWarnings(require("arrayQualityMetrics", quietly=TRUE))) {
##   qanorm = arrayQualityMetrics(AEsetnorm, 
##     outdir = "QAnorm", 
##     intgroup = fac, 
##     grouprep = TRUE)
## }


###################################################
### code chunk number 13: limma
###################################################
library("limma")
facs =  pData(AEset)[,fac]
facs[facs[,2]=="female",2]="F"
facs[facs[,2]=="male",2]="M"
facs[facs[,1]=="Parkinson disease",1]="parkinson"
facs = paste(facs[,1],facs[,2], sep=".")
f = factor(facs)
design = model.matrix(~0+f)
colnames(design) = levels(f)
fit = lmFit(AEsetnorm, design)
cont.matrix = makeContrasts(normal.FvsM = normal.F-normal.M,             
    parkinson.FvsM = parkinson.F-parkinson.M,  
    Diff=(parkinson.F-parkinson.M)-(normal.F-normal.M),
    levels=design)
fit2 = contrasts.fit(fit, cont.matrix)
fit2 = eBayes(fit2)
res = topTable(fit2, coef = "parkinson.FvsM", adjust = "BH")
